@@ -142,7 +142,20 @@ class ServicesCommands(Commands):
             CommandStep(
                 cmd=['pipenv', 'run', 'invenio', 'rdm-records', 'demo'],
                 env={'PIPENV_VERBOSITY': "-1"},
-                message="Creatin demo records..."
+                message="Creating demo records..."
+            )
+        ]
+
+        return steps
+
+    def fixtures(self):
+        """Steps to set up the required fixtures for the instance."""
+        command = ['pipenv', 'run', 'invenio', 'rdm-records', 'fixtures']
+        steps = [
+            CommandStep(
+                cmd=command,
+                env={'PIPENV_VERBOSITY': "-1"},
+                message="Creating fixtures..."
             )
         ]
 
@@ -165,6 +178,7 @@ class ServicesCommands(Commands):
             steps.extend(self._cleanup())
 
         steps.extend(self._setup())
+        steps.extend(self.fixtures())
 
         if demo_data:
             steps.extend(self.demo())
